package com.casic.missiles.modular.system.dao;

import com.casic.missiles.core.datascope.DataScope;
import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;

public interface StatisticMapper{
    List<Map<String,Object>> wellStaticsByDept(@Param("dataScope")DataScope dataScope);
    List<Map<String,Object>> wellStaticsByType(@Param("deptIds")String deptIds);
    List<Map<String,Object>> deviceStaticsByType(@Param("deptIds")String deptIds);
    List<Map<String,Object>> deviceStaticsByDept(@Param("dataScope")DataScope dataScope,@Param("deviceType")String deviceType);
    Map<String,Object> deviceStaticsByStatus(@Param("deptIds")String deptIds);
    List<Map<String,Object>> jobsByDept(@Param("dataScope")DataScope dataScope,@Param("beginTime")String beginTime,@Param("endTime")String endTime,@Param("deviceType")String deviceType);
    Map<String,Object> jobsByDeptId(@Param("deptIds")String deptIds,@Param("beginTime")String beginTime,@Param("endTime")String endTime);
}
